@@ -1,7 +1,7 @@
 """
 Type annotations for route53-recovery-cluster service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs/)
 
 Usage::
 
@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, Sequence
+from typing import Dict, List, Sequence
 
 from typing_extensions import NotRequired
 
@@ -27,7 +27,12 @@ else:
 __all__ = (
     "GetRoutingControlStateRequestRequestTypeDef",
     "GetRoutingControlStateResponseTypeDef",
+    "ListRoutingControlsRequestListRoutingControlsPaginateTypeDef",
+    "ListRoutingControlsRequestRequestTypeDef",
+    "ListRoutingControlsResponseTypeDef",
+    "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
+    "RoutingControlTypeDef",
     "UpdateRoutingControlStateEntryTypeDef",
     "UpdateRoutingControlStateRequestRequestTypeDef",
     "UpdateRoutingControlStatesRequestRequestTypeDef",
@@ -45,10 +50,49 @@ GetRoutingControlStateResponseTypeDef = TypedDict(
     {
         "RoutingControlArn": str,
         "RoutingControlState": RoutingControlStateType,
+        "RoutingControlName": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+ListRoutingControlsRequestListRoutingControlsPaginateTypeDef = TypedDict(
+    "ListRoutingControlsRequestListRoutingControlsPaginateTypeDef",
+    {
+        "ControlPanelArn": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+ListRoutingControlsRequestRequestTypeDef = TypedDict(
+    "ListRoutingControlsRequestRequestTypeDef",
+    {
+        "ControlPanelArn": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListRoutingControlsResponseTypeDef = TypedDict(
+    "ListRoutingControlsResponseTypeDef",
+    {
+        "RoutingControls": List["RoutingControlTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -60,6 +104,18 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RoutingControlTypeDef = TypedDict(
+    "RoutingControlTypeDef",
+    {
+        "ControlPanelArn": str,
+        "ControlPanelName": str,
+        "RoutingControlArn": str,
+        "RoutingControlName": str,
+        "RoutingControlState": RoutingControlStateType,
+    },
+    total=False,
+)
+
 UpdateRoutingControlStateEntryTypeDef = TypedDict(
     "UpdateRoutingControlStateEntryTypeDef",
     {
